@@ -2,7 +2,8 @@ from typing import Callable
 from fastapi.routing import APIRoute
 from fastapi import Request, Response
 from time import time
-from .logg import logger
+from ..logs import logger
+import datetime
 
 class RouteTimer(APIRoute):
     def get_route_handler(self) -> Callable:
@@ -32,3 +33,16 @@ class TimedRoute(APIRoute):
         return custom_route_handler
 
 
+# @app.middleware("http")
+# async def middleware_log(request: Request, call_next):
+#     start_time = datetime.now()
+#     method_name = request.method
+#     # q_param = request.query_params
+#     # p_param = request.path_params
+#     content = f'''{method_name}: {request.url}'''
+#     logger.info(content)
+#     response = await call_next(request)
+#     process_time = datetime.now() - start_time
+
+#     response.headers["X-Time-Elapsed"] = str(process_time)
+#     return response
